#!/bin/bash

NETDIR=/etc/network/interfaces.d
WIRED_DEV="enp2s0"
SCRIPT_PATH=/usr/lib/truefitness/truetouch/scripts

if [[ $($SCRIPT_PATH/detect_pcie.sh ) = "yes" || $($SCRIPT_PATH/tunertype.sh) = "H1265" ]]; then
  WIFI_DEV="wlp6s0"
else
WIFI_DEV="wlp5s0"
fi

# pass -b at the beginning to allow two interfaces
# NOTE: it must be at the beginning, before the other arguments
ALLOW_BOTH="0"
while getopts ":b" opt; do
  case $opt in
  b)
    ALLOW_BOTH="1"
    shift
    ;;
  \?)
    echo "Invalid option: -$OPTARG" >&2
    ;;
  esac
done

INTERFACE=$1
ESSID=$2
PASS=$3
#KEYTYPE=$4

echo stopping networking
sudo ifdown -a --exclude=lo

if [[ "$INTERFACE" == "$WIRED_DEV" ]] ; then
    echo enabling ethernet interface
    sudo ln -sf $NETDIR/$WIRED_DEV $NETDIR/$WIRED_DEV.cfg
    if [ $ALLOW_BOTH = "0" ]; then
        sudo unlink $NETDIR/$WIFI_DEV.cfg 2>/dev/null
    fi
else
    echo writing wireless authentication setup
    sudo sh -c "echo 'network={'  > /etc/wpa_supplicant.conf"
    sudo sh -c "echo '	ssid=\"$ESSID\"' >> /etc/wpa_supplicant.conf"

    if [ ! -z "$PASS" ] ; then
    	sudo sh -c "echo '	psk=\"$PASS\"' >> /etc/wpa_supplicant.conf"
    else
    	sudo sh -c "echo '	key_mgmt=NONE' >> /etc/wpa_supplicant.conf"
    fi

    sudo sh -c "echo '}' >> /etc/wpa_supplicant.conf"

#network={
#        ssid="$ESSID"
#        psk="$PASS"
#	key_mgmt=$KEYTYPE
#}

#End-of-data

    echo switching interface to wireless
    sudo ln -sf $NETDIR/$WIFI_DEV $NETDIR/$WIFI_DEV.cfg
    if [ $ALLOW_BOTH = "0" ]; then
        sudo unlink $NETDIR/$WIRED_DEV.cfg 2>/dev/null
    fi
fi

sync
echo restarting networking...

if [ "$INTERFACE" == "$WIRED_DEV" ] || [ "$ALLOW_BOTH" == "1" ]; then
    echo restarting "Wired network interface.."
    timeout 60s bash -c "sudo ifup $WIRED_DEV --exclude=lo"
else
	echo "Must be wifi only"
fi


if [[ "$INTERFACE" == "$WIFI_DEV" ]]; then
    echo restarting "Wifi network interface.."
    timeout 60s bash -c "sudo ifup $WIFI_DEV --exclude=lo"
fi
